# Copyright © 2022 Arrikto Inc.  All Rights Reserved.

"""CIFAR10 handler Definition.

This script defines a simple TorchServe handler.
"""

from torchvision import transforms
from torch.profiler import ProfilerActivity
from ts.torch_handler.image_classifier import ImageClassifier


class Cifar10Classifier(ImageClassifier):
    """Cifar10Classifier Handler."""

    class_names = ["plane", "car", "bird", "cat", "deer",
                   "dog", "frog", "horse", "ship", "truck"]

    image_processing = transforms.Compose([
        transforms.ToTensor(),
        transforms.Normalize((0.5, 0.5, 0.5), (0.5, 0.5, 0.5))])

    def __init__(self):
        super(Cifar10Classifier, self).__init__()
        self.profiler_args = {
            "activities": [ProfilerActivity.CPU],
            "record_shapes": True,
        }

    def postprocess(self, data):
        """Convert the predicted output response to a label.

        Args:
            data (list): The predicted output response.

        Returns:
            list : A list of dictionaries with processed predictions.
        """
        pred = data.argmax(1).tolist()
        labels = [self.class_names[p] for p in pred]
        return labels
